==> cloud-3.0.0-rc1.tar.gz: cloud/src/Plugin/cloud/store/CloudStorePluginManagerInterface.php <==
<?php

namespace Drupal\cloud\Plugin\cloud\store;

use Drupal\cloud\Entity\CloudStoreInterface;
use Drupal\Component\Plugin\PluginManagerInterface;

/**
 * Defines an interface for cloud_store_plugin managers.
 */
interface CloudStorePluginManagerInterface extends PluginManagerInterface {

  /**
   * Build the header array for CloudStore.
   *
   * @param string $cloud_store_type
   *   Cloud store type.
   *
   * @return array
   *   An array of headers.
   */
  public function buildListHeader($cloud_store_type);

  /**
   * Build the row for CloudStoreListBuilder.
   *
   * @param \Drupal\cloud\Entity\CloudStoreInterface $entity
   *   A loaded cloud server template entity.
   *
   * @return array
   *   An array of values for the row.
   */
  public function buildListRow(CloudStoreInterface $entity);

  /**
   * Load a plugin using the cloud_context.
   *
   * @param string $cloud_store_type
   *   Cloud store type(Bundle).
   *
   * @return CloudStorePluginInterface
   *   loaded CloudStorePlugin.
   */
  public function loadPluginVariant($cloud_store_type);

  /**
   * Update cloud store list.
   *
   * @param string $cloud_store_type
   *   Cloud store type(Bundle).
   *
   * @return mixed
   *   An associative array with a redirect route and any parameters to build
   *   the route.
   */
  public function updateCloudStoreList($cloud_store_type);

  /**
   * Load all configuration entities for a given bundle.
   *
   * @param string $entity_bundle
   *   The bundle to load.
   *
   * @return mixed
   *   An array of cloud_store entities.
   */
  public function loadConfigEntities($entity_bundle);

  /**
   * Load a config entity.
   *
   * @return \Drupal\cloud\Entity\CloudStore
   *   The cloud service provider (CloudStore) entity.
   */
  public function loadConfigEntity();

}

==> cloud-3.2.0.tar.gz: cloud/src/Plugin/cloud/store/CloudStorePluginManagerInterface.php <==
<?php

namespace Drupal\cloud\Plugin\cloud\store;

use Drupal\cloud\Entity\CloudStoreInterface;
use Drupal\Component\Plugin\PluginManagerInterface;

/**
 * Defines an interface for cloud_store_plugin managers.
 */
interface CloudStorePluginManagerInterface extends PluginManagerInterface {

  /**
   * Build the header array for CloudStore.
   *
   * @param string $cloud_store_type
   *   Cloud store type.
   *
   * @return array
   *   An array of headers.
   */
  public function buildListHeader($cloud_store_type);

  /**
   * Build the row for CloudStoreListBuilder.
   *
   * @param \Drupal\cloud\Entity\CloudStoreInterface $entity
   *   A loaded cloud launch template entity.
   *
   * @return array
   *   An array of values for the row.
   */
  public function buildListRow(CloudStoreInterface $entity);

  /**
   * Load a plugin using the cloud_context.
   *
   * @param string $cloud_store_type
   *   Cloud store type (Bundle).
   *
   * @return CloudStorePluginInterface
   *   loaded CloudStorePlugin.
   */
  public function loadPluginVariant($cloud_store_type);

  /**
   * Update cloud store list.
   *
   * @param string $cloud_store_type
   *   Cloud store type (Bundle).
   *
   * @return mixed
   *   An associative array with a redirect route and any parameters to build
   *   the route.
   */
  public function updateCloudStoreList($cloud_store_type);

  /**
   * Load all configuration entities for a given bundle.
   *
   * @param string $entity_bundle
   *   The bundle to load.
   *
   * @return mixed
   *   An array of cloud_store entities.
   */
  public function loadConfigEntities($entity_bundle);

  /**
   * Load a config entity.
   *
   * @return \Drupal\cloud\Entity\CloudStore
   *   The cloud service provider (CloudStore) entity.
   */
  public function loadConfigEntity();

}
